// source: postal_verification.proto
/**
 * @fileoverview
 * @enhanceable
 * @suppress {missingRequire} reports error on implicit type usages.
 * @suppress {messageConventions} JS Compiler reports an error if a variable or
 *     field starts with 'MSG_' and isn't a translatable message.
 * @public
 */
// GENERATED CODE -- DO NOT EDIT!
/* eslint-disable */
// @ts-nocheck

var jspb = require('google-protobuf');
var goog = jspb;
var global =
    (typeof globalThis !== 'undefined' && globalThis) ||
    (typeof window !== 'undefined' && window) ||
    (typeof global !== 'undefined' && global) ||
    (typeof self !== 'undefined' && self) ||
    (function () { return this; }).call(null) ||
    Function('return this')();

var google_protobuf_empty_pb = require('google-protobuf/google/protobuf/empty_pb.js');
goog.object.extend(proto, google_protobuf_empty_pb);
var google_protobuf_timestamp_pb = require('google-protobuf/google/protobuf/timestamp_pb.js');
goog.object.extend(proto, google_protobuf_timestamp_pb);
var annotations_pb = require('./annotations_pb.js');
goog.object.extend(proto, annotations_pb);
goog.exportSymbol('proto.org.couchers.api.postal_verification.CancelPostalVerificationReq', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.PostalAddress', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.PostalVerificationStatus', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.VerifyPostalCodeReq', null, global);
goog.exportSymbol('proto.org.couchers.api.postal_verification.VerifyPostalCodeRes', null, global);
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.PostalAddress = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.PostalAddress, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.PostalAddress.displayName = 'proto.org.couchers.api.postal_verification.PostalAddress';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.displayName = 'proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.displayName = 'proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.displayName = 'proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.displayName = 'proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.displayName = 'proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.displayName = 'proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.VerifyPostalCodeReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.displayName = 'proto.org.couchers.api.postal_verification.VerifyPostalCodeReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.VerifyPostalCodeRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.displayName = 'proto.org.couchers.api.postal_verification.VerifyPostalCodeRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.CancelPostalVerificationReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.displayName = 'proto.org.couchers.api.postal_verification.CancelPostalVerificationReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.displayName = 'proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.repeatedFields_, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.displayName = 'proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes';
}
/**
 * Generated by JsPbCodeGenerator.
 * @param {Array=} opt_data Optional initial data array, typically from a
 * server response, or constructed directly in Javascript. The array is used
 * in place and becomes part of the constructed object. It is not cloned.
 * If no data is provided, the constructed object will be empty, but still
 * valid.
 * @extends {jspb.Message}
 * @constructor
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary = function(opt_data) {
  jspb.Message.initialize(this, opt_data, 0, -1, null, null);
};
goog.inherits(proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary, jspb.Message);
if (goog.DEBUG && !COMPILED) {
  /**
   * @public
   * @override
   */
  proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.displayName = 'proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary';
}



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.PostalAddress.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.PostalAddress} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.PostalAddress.toObject = function(includeInstance, msg) {
  var f, obj = {
    addressLine1: jspb.Message.getFieldWithDefault(msg, 1, ""),
    addressLine2: jspb.Message.getFieldWithDefault(msg, 2, ""),
    city: jspb.Message.getFieldWithDefault(msg, 3, ""),
    state: jspb.Message.getFieldWithDefault(msg, 4, ""),
    postalCode: jspb.Message.getFieldWithDefault(msg, 5, ""),
    countryCode: jspb.Message.getFieldWithDefault(msg, 6, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress}
 */
proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.PostalAddress;
  return proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.PostalAddress} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress}
 */
proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {string} */ (reader.readString());
      msg.setAddressLine1(value);
      break;
    case 2:
      var value = /** @type {string} */ (reader.readString());
      msg.setAddressLine2(value);
      break;
    case 3:
      var value = /** @type {string} */ (reader.readString());
      msg.setCity(value);
      break;
    case 4:
      var value = /** @type {string} */ (reader.readString());
      msg.setState(value);
      break;
    case 5:
      var value = /** @type {string} */ (reader.readString());
      msg.setPostalCode(value);
      break;
    case 6:
      var value = /** @type {string} */ (reader.readString());
      msg.setCountryCode(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.PostalAddress.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.PostalAddress} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.PostalAddress.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getAddressLine1();
  if (f.length > 0) {
    writer.writeString(
      1,
      f
    );
  }
  f = message.getAddressLine2();
  if (f.length > 0) {
    writer.writeString(
      2,
      f
    );
  }
  f = message.getCity();
  if (f.length > 0) {
    writer.writeString(
      3,
      f
    );
  }
  f = message.getState();
  if (f.length > 0) {
    writer.writeString(
      4,
      f
    );
  }
  f = message.getPostalCode();
  if (f.length > 0) {
    writer.writeString(
      5,
      f
    );
  }
  f = message.getCountryCode();
  if (f.length > 0) {
    writer.writeString(
      6,
      f
    );
  }
};


/**
 * optional string address_line_1 = 1;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.getAddressLine1 = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 1, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress} returns this
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.setAddressLine1 = function(value) {
  return jspb.Message.setProto3StringField(this, 1, value);
};


/**
 * optional string address_line_2 = 2;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.getAddressLine2 = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 2, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress} returns this
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.setAddressLine2 = function(value) {
  return jspb.Message.setProto3StringField(this, 2, value);
};


/**
 * optional string city = 3;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.getCity = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 3, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress} returns this
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.setCity = function(value) {
  return jspb.Message.setProto3StringField(this, 3, value);
};


/**
 * optional string state = 4;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.getState = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 4, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress} returns this
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.setState = function(value) {
  return jspb.Message.setProto3StringField(this, 4, value);
};


/**
 * optional string postal_code = 5;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.getPostalCode = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 5, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress} returns this
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.setPostalCode = function(value) {
  return jspb.Message.setProto3StringField(this, 5, value);
};


/**
 * optional string country_code = 6;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.getCountryCode = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 6, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.PostalAddress} returns this
 */
proto.org.couchers.api.postal_verification.PostalAddress.prototype.setCountryCode = function(value) {
  return jspb.Message.setProto3StringField(this, 6, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    address: (f = msg.getAddress()) && proto.org.couchers.api.postal_verification.PostalAddress.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq;
  return proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.api.postal_verification.PostalAddress;
      reader.readMessage(value,proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinaryFromReader);
      msg.setAddress(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getAddress();
  if (f != null) {
    writer.writeMessage(
      1,
      f,
      proto.org.couchers.api.postal_verification.PostalAddress.serializeBinaryToWriter
    );
  }
};


/**
 * optional PostalAddress address = 1;
 * @return {?proto.org.couchers.api.postal_verification.PostalAddress}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.prototype.getAddress = function() {
  return /** @type{?proto.org.couchers.api.postal_verification.PostalAddress} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.api.postal_verification.PostalAddress, 1));
};


/**
 * @param {?proto.org.couchers.api.postal_verification.PostalAddress|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} returns this
*/
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.prototype.setAddress = function(value) {
  return jspb.Message.setWrapperField(this, 1, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq} returns this
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.prototype.clearAddress = function() {
  return this.setAddress(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationReq.prototype.hasAddress = function() {
  return jspb.Message.getField(this, 1) != null;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    postalVerificationAttemptId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    correctedAddress: (f = msg.getCorrectedAddress()) && proto.org.couchers.api.postal_verification.PostalAddress.toObject(includeInstance, f),
    addressWasCorrected: jspb.Message.getBooleanFieldWithDefault(msg, 3, false)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes;
  return proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setPostalVerificationAttemptId(value);
      break;
    case 2:
      var value = new proto.org.couchers.api.postal_verification.PostalAddress;
      reader.readMessage(value,proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinaryFromReader);
      msg.setCorrectedAddress(value);
      break;
    case 3:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setAddressWasCorrected(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getPostalVerificationAttemptId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getCorrectedAddress();
  if (f != null) {
    writer.writeMessage(
      2,
      f,
      proto.org.couchers.api.postal_verification.PostalAddress.serializeBinaryToWriter
    );
  }
  f = message.getAddressWasCorrected();
  if (f) {
    writer.writeBool(
      3,
      f
    );
  }
};


/**
 * optional int64 postal_verification_attempt_id = 1;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.getPostalVerificationAttemptId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} returns this
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.setPostalVerificationAttemptId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional PostalAddress corrected_address = 2;
 * @return {?proto.org.couchers.api.postal_verification.PostalAddress}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.getCorrectedAddress = function() {
  return /** @type{?proto.org.couchers.api.postal_verification.PostalAddress} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.api.postal_verification.PostalAddress, 2));
};


/**
 * @param {?proto.org.couchers.api.postal_verification.PostalAddress|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} returns this
*/
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.setCorrectedAddress = function(value) {
  return jspb.Message.setWrapperField(this, 2, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} returns this
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.clearCorrectedAddress = function() {
  return this.setCorrectedAddress(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.hasCorrectedAddress = function() {
  return jspb.Message.getField(this, 2) != null;
};


/**
 * optional bool address_was_corrected = 3;
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.getAddressWasCorrected = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 3, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes} returns this
 */
proto.org.couchers.api.postal_verification.InitiatePostalVerificationRes.prototype.setAddressWasCorrected = function(value) {
  return jspb.Message.setProto3BooleanField(this, 3, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    postalVerificationAttemptId: jspb.Message.getFieldWithDefault(msg, 1, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq;
  return proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setPostalVerificationAttemptId(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getPostalVerificationAttemptId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
};


/**
 * optional int64 postal_verification_attempt_id = 1;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.prototype.getPostalVerificationAttemptId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq} returns this
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressReq.prototype.setPostalVerificationAttemptId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.toObject = function(includeInstance, msg) {
  var f, obj = {

  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes;
  return proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ConfirmPostalAddressRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    postalVerificationAttemptId: jspb.Message.getFieldWithDefault(msg, 1, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq;
  return proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setPostalVerificationAttemptId(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getPostalVerificationAttemptId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
};


/**
 * optional int64 postal_verification_attempt_id = 1;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.prototype.getPostalVerificationAttemptId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusReq.prototype.setPostalVerificationAttemptId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    hasPostalVerification: jspb.Message.getBooleanFieldWithDefault(msg, 1, false),
    hasActiveAttempt: jspb.Message.getBooleanFieldWithDefault(msg, 2, false),
    postalVerificationAttemptId: jspb.Message.getFieldWithDefault(msg, 3, 0),
    status: jspb.Message.getFieldWithDefault(msg, 4, 0),
    address: (f = msg.getAddress()) && proto.org.couchers.api.postal_verification.PostalAddress.toObject(includeInstance, f),
    created: (f = msg.getCreated()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    postcardSentAt: (f = msg.getPostcardSentAt()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    canInitiateNewAttempt: jspb.Message.getBooleanFieldWithDefault(msg, 8, false),
    nextAttemptAllowedAt: (f = msg.getNextAttemptAllowedAt()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes;
  return proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setHasPostalVerification(value);
      break;
    case 2:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setHasActiveAttempt(value);
      break;
    case 3:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setPostalVerificationAttemptId(value);
      break;
    case 4:
      var value = /** @type {!proto.org.couchers.api.postal_verification.PostalVerificationStatus} */ (reader.readEnum());
      msg.setStatus(value);
      break;
    case 5:
      var value = new proto.org.couchers.api.postal_verification.PostalAddress;
      reader.readMessage(value,proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinaryFromReader);
      msg.setAddress(value);
      break;
    case 6:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setCreated(value);
      break;
    case 7:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setPostcardSentAt(value);
      break;
    case 8:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setCanInitiateNewAttempt(value);
      break;
    case 9:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setNextAttemptAllowedAt(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getHasPostalVerification();
  if (f) {
    writer.writeBool(
      1,
      f
    );
  }
  f = message.getHasActiveAttempt();
  if (f) {
    writer.writeBool(
      2,
      f
    );
  }
  f = message.getPostalVerificationAttemptId();
  if (f !== 0) {
    writer.writeInt64(
      3,
      f
    );
  }
  f = message.getStatus();
  if (f !== 0.0) {
    writer.writeEnum(
      4,
      f
    );
  }
  f = message.getAddress();
  if (f != null) {
    writer.writeMessage(
      5,
      f,
      proto.org.couchers.api.postal_verification.PostalAddress.serializeBinaryToWriter
    );
  }
  f = message.getCreated();
  if (f != null) {
    writer.writeMessage(
      6,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getPostcardSentAt();
  if (f != null) {
    writer.writeMessage(
      7,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getCanInitiateNewAttempt();
  if (f) {
    writer.writeBool(
      8,
      f
    );
  }
  f = message.getNextAttemptAllowedAt();
  if (f != null) {
    writer.writeMessage(
      9,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
};


/**
 * optional bool has_postal_verification = 1;
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getHasPostalVerification = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 1, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setHasPostalVerification = function(value) {
  return jspb.Message.setProto3BooleanField(this, 1, value);
};


/**
 * optional bool has_active_attempt = 2;
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getHasActiveAttempt = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 2, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setHasActiveAttempt = function(value) {
  return jspb.Message.setProto3BooleanField(this, 2, value);
};


/**
 * optional int64 postal_verification_attempt_id = 3;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getPostalVerificationAttemptId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 3, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setPostalVerificationAttemptId = function(value) {
  return jspb.Message.setProto3IntField(this, 3, value);
};


/**
 * optional PostalVerificationStatus status = 4;
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationStatus}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getStatus = function() {
  return /** @type {!proto.org.couchers.api.postal_verification.PostalVerificationStatus} */ (jspb.Message.getFieldWithDefault(this, 4, 0));
};


/**
 * @param {!proto.org.couchers.api.postal_verification.PostalVerificationStatus} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setStatus = function(value) {
  return jspb.Message.setProto3EnumField(this, 4, value);
};


/**
 * optional PostalAddress address = 5;
 * @return {?proto.org.couchers.api.postal_verification.PostalAddress}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getAddress = function() {
  return /** @type{?proto.org.couchers.api.postal_verification.PostalAddress} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.api.postal_verification.PostalAddress, 5));
};


/**
 * @param {?proto.org.couchers.api.postal_verification.PostalAddress|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
*/
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setAddress = function(value) {
  return jspb.Message.setWrapperField(this, 5, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.clearAddress = function() {
  return this.setAddress(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.hasAddress = function() {
  return jspb.Message.getField(this, 5) != null;
};


/**
 * optional google.protobuf.Timestamp created = 6;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getCreated = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 6));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
*/
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setCreated = function(value) {
  return jspb.Message.setWrapperField(this, 6, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.clearCreated = function() {
  return this.setCreated(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.hasCreated = function() {
  return jspb.Message.getField(this, 6) != null;
};


/**
 * optional google.protobuf.Timestamp postcard_sent_at = 7;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getPostcardSentAt = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 7));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
*/
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setPostcardSentAt = function(value) {
  return jspb.Message.setWrapperField(this, 7, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.clearPostcardSentAt = function() {
  return this.setPostcardSentAt(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.hasPostcardSentAt = function() {
  return jspb.Message.getField(this, 7) != null;
};


/**
 * optional bool can_initiate_new_attempt = 8;
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getCanInitiateNewAttempt = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 8, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setCanInitiateNewAttempt = function(value) {
  return jspb.Message.setProto3BooleanField(this, 8, value);
};


/**
 * optional google.protobuf.Timestamp next_attempt_allowed_at = 9;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.getNextAttemptAllowedAt = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 9));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
*/
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.setNextAttemptAllowedAt = function(value) {
  return jspb.Message.setWrapperField(this, 9, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes} returns this
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.clearNextAttemptAllowedAt = function() {
  return this.setNextAttemptAllowedAt(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.GetPostalVerificationStatusRes.prototype.hasNextAttemptAllowedAt = function() {
  return jspb.Message.getField(this, 9) != null;
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    code: jspb.Message.getFieldWithDefault(msg, 1, "")
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.VerifyPostalCodeReq;
  return proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {string} */ (reader.readString());
      msg.setCode(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getCode();
  if (f.length > 0) {
    writer.writeString(
      1,
      f
    );
  }
};


/**
 * optional string code = 1;
 * @return {string}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.prototype.getCode = function() {
  return /** @type {string} */ (jspb.Message.getFieldWithDefault(this, 1, ""));
};


/**
 * @param {string} value
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeReq} returns this
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeReq.prototype.setCode = function(value) {
  return jspb.Message.setProto3StringField(this, 1, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    success: jspb.Message.getBooleanFieldWithDefault(msg, 1, false),
    remainingAttempts: jspb.Message.getFieldWithDefault(msg, 2, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.VerifyPostalCodeRes;
  return proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {boolean} */ (reader.readBool());
      msg.setSuccess(value);
      break;
    case 2:
      var value = /** @type {number} */ (reader.readInt32());
      msg.setRemainingAttempts(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getSuccess();
  if (f) {
    writer.writeBool(
      1,
      f
    );
  }
  f = message.getRemainingAttempts();
  if (f !== 0) {
    writer.writeInt32(
      2,
      f
    );
  }
};


/**
 * optional bool success = 1;
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.prototype.getSuccess = function() {
  return /** @type {boolean} */ (jspb.Message.getBooleanFieldWithDefault(this, 1, false));
};


/**
 * @param {boolean} value
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes} returns this
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.prototype.setSuccess = function(value) {
  return jspb.Message.setProto3BooleanField(this, 1, value);
};


/**
 * optional int32 remaining_attempts = 2;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.prototype.getRemainingAttempts = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.VerifyPostalCodeRes} returns this
 */
proto.org.couchers.api.postal_verification.VerifyPostalCodeRes.prototype.setRemainingAttempts = function(value) {
  return jspb.Message.setProto3IntField(this, 2, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.toObject = function(includeInstance, msg) {
  var f, obj = {
    postalVerificationAttemptId: jspb.Message.getFieldWithDefault(msg, 1, 0)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq}
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.CancelPostalVerificationReq;
  return proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq}
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setPostalVerificationAttemptId(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getPostalVerificationAttemptId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
};


/**
 * optional int64 postal_verification_attempt_id = 1;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.prototype.getPostalVerificationAttemptId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.CancelPostalVerificationReq} returns this
 */
proto.org.couchers.api.postal_verification.CancelPostalVerificationReq.prototype.setPostalVerificationAttemptId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.toObject = function(includeInstance, msg) {
  var f, obj = {

  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq;
  return proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
};



/**
 * List of repeated fields within this message type.
 * @private {!Array<number>}
 * @const
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.repeatedFields_ = [1];



if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.toObject = function(includeInstance, msg) {
  var f, obj = {
    attemptsList: jspb.Message.toObjectList(msg.getAttemptsList(),
    proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.toObject, includeInstance)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes;
  return proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = new proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary;
      reader.readMessage(value,proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.deserializeBinaryFromReader);
      msg.addAttempts(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getAttemptsList();
  if (f.length > 0) {
    writer.writeRepeatedMessage(
      1,
      f,
      proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.serializeBinaryToWriter
    );
  }
};


/**
 * repeated PostalVerificationAttemptSummary attempts = 1;
 * @return {!Array<!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary>}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.prototype.getAttemptsList = function() {
  return /** @type{!Array<!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary>} */ (
    jspb.Message.getRepeatedWrapperField(this, proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary, 1));
};


/**
 * @param {!Array<!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary>} value
 * @return {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes} returns this
*/
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.prototype.setAttemptsList = function(value) {
  return jspb.Message.setRepeatedWrapperField(this, 1, value);
};


/**
 * @param {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary=} opt_value
 * @param {number=} opt_index
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary}
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.prototype.addAttempts = function(opt_value, opt_index) {
  return jspb.Message.addToRepeatedWrapperField(this, 1, opt_value, proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary, opt_index);
};


/**
 * Clears the list making it empty but non-null.
 * @return {!proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes} returns this
 */
proto.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes.prototype.clearAttemptsList = function() {
  return this.setAttemptsList([]);
};





if (jspb.Message.GENERATE_TO_OBJECT) {
/**
 * Creates an object representation of this proto.
 * Field names that are reserved in JavaScript and will be renamed to pb_name.
 * Optional fields that are not set will be set to undefined.
 * To access a reserved field use, foo.pb_<name>, eg, foo.pb_default.
 * For the list of reserved names please see:
 *     net/proto2/compiler/js/internal/generator.cc#kKeyword.
 * @param {boolean=} opt_includeInstance Deprecated. whether to include the
 *     JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @return {!Object}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.toObject = function(opt_includeInstance) {
  return proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.toObject(opt_includeInstance, this);
};


/**
 * Static version of the {@see toObject} method.
 * @param {boolean|undefined} includeInstance Deprecated. Whether to include
 *     the JSPB instance for transitional soy proto support:
 *     http://goto/soy-param-migration
 * @param {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} msg The msg instance to transform.
 * @return {!Object}
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.toObject = function(includeInstance, msg) {
  var f, obj = {
    postalVerificationAttemptId: jspb.Message.getFieldWithDefault(msg, 1, 0),
    status: jspb.Message.getFieldWithDefault(msg, 2, 0),
    address: (f = msg.getAddress()) && proto.org.couchers.api.postal_verification.PostalAddress.toObject(includeInstance, f),
    created: (f = msg.getCreated()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f),
    verifiedAt: (f = msg.getVerifiedAt()) && google_protobuf_timestamp_pb.Timestamp.toObject(includeInstance, f)
  };

  if (includeInstance) {
    obj.$jspbMessageInstance = msg;
  }
  return obj;
};
}


/**
 * Deserializes binary data (in protobuf wire format).
 * @param {jspb.ByteSource} bytes The bytes to deserialize.
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.deserializeBinary = function(bytes) {
  var reader = new jspb.BinaryReader(bytes);
  var msg = new proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary;
  return proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.deserializeBinaryFromReader(msg, reader);
};


/**
 * Deserializes binary data (in protobuf wire format) from the
 * given reader into the given message object.
 * @param {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} msg The message object to deserialize into.
 * @param {!jspb.BinaryReader} reader The BinaryReader to use.
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.deserializeBinaryFromReader = function(msg, reader) {
  while (reader.nextField()) {
    if (reader.isEndGroup()) {
      break;
    }
    var field = reader.getFieldNumber();
    switch (field) {
    case 1:
      var value = /** @type {number} */ (reader.readInt64());
      msg.setPostalVerificationAttemptId(value);
      break;
    case 2:
      var value = /** @type {!proto.org.couchers.api.postal_verification.PostalVerificationStatus} */ (reader.readEnum());
      msg.setStatus(value);
      break;
    case 3:
      var value = new proto.org.couchers.api.postal_verification.PostalAddress;
      reader.readMessage(value,proto.org.couchers.api.postal_verification.PostalAddress.deserializeBinaryFromReader);
      msg.setAddress(value);
      break;
    case 4:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setCreated(value);
      break;
    case 5:
      var value = new google_protobuf_timestamp_pb.Timestamp;
      reader.readMessage(value,google_protobuf_timestamp_pb.Timestamp.deserializeBinaryFromReader);
      msg.setVerifiedAt(value);
      break;
    default:
      reader.skipField();
      break;
    }
  }
  return msg;
};


/**
 * Serializes the message to binary data (in protobuf wire format).
 * @return {!Uint8Array}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.serializeBinary = function() {
  var writer = new jspb.BinaryWriter();
  proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.serializeBinaryToWriter(this, writer);
  return writer.getResultBuffer();
};


/**
 * Serializes the given message to binary data (in protobuf wire
 * format), writing to the given BinaryWriter.
 * @param {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} message
 * @param {!jspb.BinaryWriter} writer
 * @suppress {unusedLocalVariables} f is only used for nested messages
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.serializeBinaryToWriter = function(message, writer) {
  var f = undefined;
  f = message.getPostalVerificationAttemptId();
  if (f !== 0) {
    writer.writeInt64(
      1,
      f
    );
  }
  f = message.getStatus();
  if (f !== 0.0) {
    writer.writeEnum(
      2,
      f
    );
  }
  f = message.getAddress();
  if (f != null) {
    writer.writeMessage(
      3,
      f,
      proto.org.couchers.api.postal_verification.PostalAddress.serializeBinaryToWriter
    );
  }
  f = message.getCreated();
  if (f != null) {
    writer.writeMessage(
      4,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
  f = message.getVerifiedAt();
  if (f != null) {
    writer.writeMessage(
      5,
      f,
      google_protobuf_timestamp_pb.Timestamp.serializeBinaryToWriter
    );
  }
};


/**
 * optional int64 postal_verification_attempt_id = 1;
 * @return {number}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.getPostalVerificationAttemptId = function() {
  return /** @type {number} */ (jspb.Message.getFieldWithDefault(this, 1, 0));
};


/**
 * @param {number} value
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.setPostalVerificationAttemptId = function(value) {
  return jspb.Message.setProto3IntField(this, 1, value);
};


/**
 * optional PostalVerificationStatus status = 2;
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationStatus}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.getStatus = function() {
  return /** @type {!proto.org.couchers.api.postal_verification.PostalVerificationStatus} */ (jspb.Message.getFieldWithDefault(this, 2, 0));
};


/**
 * @param {!proto.org.couchers.api.postal_verification.PostalVerificationStatus} value
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.setStatus = function(value) {
  return jspb.Message.setProto3EnumField(this, 2, value);
};


/**
 * optional PostalAddress address = 3;
 * @return {?proto.org.couchers.api.postal_verification.PostalAddress}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.getAddress = function() {
  return /** @type{?proto.org.couchers.api.postal_verification.PostalAddress} */ (
    jspb.Message.getWrapperField(this, proto.org.couchers.api.postal_verification.PostalAddress, 3));
};


/**
 * @param {?proto.org.couchers.api.postal_verification.PostalAddress|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
*/
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.setAddress = function(value) {
  return jspb.Message.setWrapperField(this, 3, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.clearAddress = function() {
  return this.setAddress(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.hasAddress = function() {
  return jspb.Message.getField(this, 3) != null;
};


/**
 * optional google.protobuf.Timestamp created = 4;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.getCreated = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 4));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
*/
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.setCreated = function(value) {
  return jspb.Message.setWrapperField(this, 4, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.clearCreated = function() {
  return this.setCreated(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.hasCreated = function() {
  return jspb.Message.getField(this, 4) != null;
};


/**
 * optional google.protobuf.Timestamp verified_at = 5;
 * @return {?proto.google.protobuf.Timestamp}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.getVerifiedAt = function() {
  return /** @type{?proto.google.protobuf.Timestamp} */ (
    jspb.Message.getWrapperField(this, google_protobuf_timestamp_pb.Timestamp, 5));
};


/**
 * @param {?proto.google.protobuf.Timestamp|undefined} value
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
*/
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.setVerifiedAt = function(value) {
  return jspb.Message.setWrapperField(this, 5, value);
};


/**
 * Clears the message field making it undefined.
 * @return {!proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary} returns this
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.clearVerifiedAt = function() {
  return this.setVerifiedAt(undefined);
};


/**
 * Returns whether this field is set.
 * @return {boolean}
 */
proto.org.couchers.api.postal_verification.PostalVerificationAttemptSummary.prototype.hasVerifiedAt = function() {
  return jspb.Message.getField(this, 5) != null;
};


/**
 * @enum {number}
 */
proto.org.couchers.api.postal_verification.PostalVerificationStatus = {
  POSTAL_VERIFICATION_STATUS_UNKNOWN: 0,
  POSTAL_VERIFICATION_STATUS_PENDING_ADDRESS_CONFIRMATION: 1,
  POSTAL_VERIFICATION_STATUS_IN_PROGRESS: 2,
  POSTAL_VERIFICATION_STATUS_AWAITING_VERIFICATION: 3,
  POSTAL_VERIFICATION_STATUS_SUCCEEDED: 4,
  POSTAL_VERIFICATION_STATUS_FAILED: 5,
  POSTAL_VERIFICATION_STATUS_CANCELLED: 6
};

goog.object.extend(exports, proto.org.couchers.api.postal_verification);
